<?php

namespace Drupal\graphql_vertex_ai\Plugin\GraphQL\DataProducer;

use Drupal\Component\Utility\Html;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;

/**
 * The data producer for search result data.
 *
 * @DataProducer(
 *   id = "vertex_ai_html_decode",
 *   name = @Translation("HTML entity decoder"),
 *   description = @Translation("Decode HTML entities that Vertex returns"),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Text")
 *   ),
 *   consumes = {
 *     "text" = @ContextDefinition("string",
 *       label = @Translation("Text"),
 *       required = FALSE
 *     ),
 *   }
 * )
 */
class HtmlDecodeEntities extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param string|null $text
   *   The text string to entity decode.
   *
   * @return string|null
   *   The result.
   */
  public function resolve(?string $text): ?string {
    if (!empty($text)) {
      return Html::decodeEntities($text);
    }
    return NULL;
  }

}
