<?php

namespace Drupal\graphql_vertex_ai\Plugin\GraphQL\DataProducer;

use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Google\Cloud\DiscoveryEngine\V1\SearchResponse;

/**
 * The data producer for search response summaries.
 *
 * @DataProducer(
 *   id = "vertex_ai_search_response_summary_text",
 *   name = @Translation("Search response summary text"),
 *   description = @Translation("The summary text of the search response or null if empty."),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Summary text")
 *   ),
 *   consumes = {
 *     "response" = @ContextDefinition("any",
 *       label = @Translation("Search Response"),
 *       required = TRUE
 *     ),
 *   }
 * )
 */
class VertexAiSearchResponseSummaryText extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param \Google\Cloud\DiscoveryEngine\V1\SearchResponse $response
   *   The search query.
   *
   * @return string|null
   *   The result.
   */
  public function resolve(SearchResponse $response): ?string {
    $summary = $response->getSummary()->getSummaryText();
    if (!empty($summary)) {
      return trim($summary);
    }
    return NULL;
  }

}
